## password-vault - pv.py
A script that manages and generates passwords from the command line, passwords are stored in a sqlite db.
***

#### Basic Usage

Generate random password for an account:  
    `python pv.py generate [accountname]`

Generate random password:  
    `python pv.py generate`

Access stored account password:  
    `python pv.py account [accountname]`

Get list of all stored account passwords:  
    `python pv.py accounts`

Save password manually:  
    `python pv.py save [accountname]`

Update password by random generation:  
    `python pv.py generate [accountname]`

Update password by manual entry:  
    `python pv.py save [accountname]`

Delete account password:  
    `python pv.py delete [accountname]`

Delete all accounts:  
    `python pv.py delete`

